Learn R Programming

smarter (version 1.0.1)

calc_JK: calc_JK

Description

calc_JK

Usage

calc_JK(EST, LOO_EST, alpha = 0.05)

Value

A list of numeric jackknife summary mean and confidence intervals

Arguments

EST

A numeric vector of parameter estimates

LOO_EST

A numeric matrix of parameter estimates where columns correspond to each parameter and rows correspond to each leave one out estimate

alpha

A numeric value for constructing (1 - alpha) * 100% confidence intervals