print_latex_table
print_latex_table(
DATA,
repeat_VARS = NULL,
my_align = NULL,
add_table = FALSE,
fontsize = NULL,
caption = NULL,
label = NULL,
midrule1 = NULL,
latex_comment = NULL,
...
)No return value
A matrix or data.frame to present as a latex table
A string vector of colnames to avoid repeating values within a column
A string containing letters "l", "r", or "c" for left, right, and center alignment
Boolean set to TRUE to enclose tabular environment with table environment
Defaults to NULL to not specify a fontsize. Otherwise, possible values are "tiny", "footnotesize", "small", "normalsize", "large", "Large", "LARGE", "huge","Huge"
A string to include a table caption
A string to represent a latex table label
Default is set to NULL
Add a latex comment above the table for notes
arguments passed to cat