Learn R Programming

smarter (version 1.0.1)

smart_colors: smart_colors

Description

smart_colors

Usage

smart_colors(nn, alpha = 1, overwrite = FALSE)

Value

No return value.

Arguments

nn

A positive integer greater than or equal to 2

alpha

A positive numeric value less than or equal to one

overwrite

Boolean If nn = 2, setting to FALSE will force colors to be white or black