Learn R Programming

smarter (version 1.0.1)

smart_digits: smart_digits

Description

Round numeric values to specific

Usage

smart_digits(x, digits = 2)

Value

Character version of rounded numeric value

Arguments

x

A numeric vector formatted to have consistently rounded values

digits

A positive integer to regulate the number of digits to round to