Learn R Programming

smarter (version 1.0.1)

smart_dots: smart_dots

Description

Prints a series of dots every few seconds

Usage

smart_dots(wait = 300, num_dots = 30)

Value

No return value.

Arguments

wait

A number of seconds to wait before printing "."

num_dots

The number of dots to print before printing a message